require "dito_utils/version"

module DitoUtils
  class MethodRetry
    def initialize(sleep_time, retries = 10)
      @sleep_time = sleep_time
      @retries = retries
      @error_count = 0
    end
  
    def retry(error_class)
      while @error_count < @retries
        begin
          return yield
        rescue *error_class => e
          sleep(@sleep_time)
          increment_error_count
          raise e if last_try?
        end
      end
    end
  
    private
  
    def increment_error_count
      @error_count += 1
    end
  
    def last_try?
      @error_count == @retries
    end
  
  end  
end
